using System.Net.Http;
using AutoMapper;
using PTS2.BaseService;
using PTS2.Common;
using PTS2.Domain;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;

namespace PTS2.DomainApiService.Service
{
    public class CategoryService : ICategoryService
    {
        private const string LogClassName = "CategoryService";
        private readonly IMapper mapper;
        private readonly ICategoryRepository repository;
        private readonly ICommonService _commonService;

        private readonly IModuleRepository _moduleRepository;
        private readonly HttpUserContext httpUserContext;

        private readonly IHttpContextAccessor _httpContext;
        public CategoryService(IMapper _mapper
            , ICategoryRepository categoryRepository
            , ICommonService commonService
            , IModuleRepository moduleRepository
            , HttpUserContext _httpUserContext
            , IHttpContextAccessor httpContextAccessor)
        {
            mapper = _mapper;
            repository = categoryRepository;
            _commonService = commonService;
            _moduleRepository = moduleRepository;
            _httpContext = httpContextAccessor;
            httpUserContext = _httpUserContext;
        }
        public async Task<Result<CategoryDto>> Create(CategoryParam categoryParam)
        {
            try
            {
                #region 参数检查
                var reqParam = categoryParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Caption, "名称");
                ParamGuard.ValidateLength(reqParam.Caption, "节点名称", 50);
                // Caption 重复检查
                if (reqParam.ParentID != null && reqParam.ParentID != Guid.Empty)
                {
                    var existModel = (await repository.GetModelAsync(m => m.ID == reqParam.ParentID.Value)).data;
                    ParamGuard.EnsureExist(existModel, $"父ID:{reqParam.ParentID}不存在");

                    var notExistModel = (await repository.GetModelAsync(m => m.Caption == reqParam.Caption && m.ParentID == reqParam.ParentID.Value)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"名称:{reqParam.Caption}已经存在");
                }
                else
                {
                    var notExistModel = (await repository.GetModelAsync(m => m.Caption == reqParam.Caption)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"名称:{reqParam.Caption}已经存在");
                }

                #endregion 

                var model = mapper.Map<DataApi_Category>(categoryParam);
                model.ID = Guid.NewGuid();
                var cono = httpUserContext.Context.UserInfo.CompanyID;
                model.CONO = cono;

                var maxTreeCode = _commonService.GetTableMaxField("DataApi_Category", "TreeCode", $"ParentID='{model.ParentID}'");

                model.TreeCode = maxTreeCode.data.ToString().PadLeft(3, '0');
                var res = await repository.AddAsync(model);

                var dtoModel = mapper.Map<CategoryDto>(res.data);

                return new Result<CategoryDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Create=>Exception:" + ex);
                return ResultFactory.Exception<CategoryDto>(ex);
            }
        }
        public async Task<Result<CategoryDto>> Update(CategoryParam categoryParam)
        {
            try
            {
                #region 参数检查
                var reqParam = categoryParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Caption, "名称");
                ParamGuard.ValidateLength(reqParam.Caption, "节点名称", 50);

                // Caption 重复检查
                if (reqParam.ParentID != null && reqParam.ParentID != Guid.Empty)
                {
                    var existModel = (await repository.GetModelAsync(m => m.ID == reqParam.ParentID.Value)).data;
                    ParamGuard.EnsureExist(existModel, $"父ID:{reqParam.ParentID}不存在");

                    var notExistModel = (await repository.GetModelAsync(m => m.Caption == reqParam.Caption && m.ParentID == reqParam.ParentID.Value)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"名称:{reqParam.Caption}已经存在");
                }
                else
                {
                    var notExistModel = (await repository.GetModelAsync(m => m.Caption == reqParam.Caption)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"名称:{reqParam.Caption}已经存在");
                }

                #endregion 

                var model = (await repository.GetModelAsync(m => m.ID == categoryParam.ID)).data;

                model.Img = categoryParam.Img;
                model.Caption = categoryParam.Caption;
                model.ParentID = categoryParam.ParentID;
                model.CONO = categoryParam.CONO;
                var res = await repository.UpdateAsync(model);

                var dtoModel = mapper.Map<CategoryDto>(res.data);
                return new Result<CategoryDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Update=>Exception:" + ex);
                return ResultFactory.Exception<CategoryDto>(ex);
            }
        }
        public async Task<Result<CategoryDto>> Get(Guid id)
        {
            try
            {
                var res = await repository.GetModelAsync(m => m.ID == id);

                var dtoModel = mapper.Map<CategoryDto>(res.data);

                return new Result<CategoryDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Get=>Exception:" + ex);
                return ResultFactory.Exception<CategoryDto>(ex);
            }
        }
        public async Task<Result<string>> Delete(Guid id)
        {
            try
            {
                var res = await repository.DeleteAsync(m => m.ID == id);

                return new Result<string>
                {
                    data = res.data,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Delete=>Exception:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }

        public async Task<Result<List<CategoryDto>>> GetList()
        {
            try
            {
                var cono = httpUserContext.Context.UserInfo.CompanyID;
                var res = await repository.GetAll().Where(m => m.CONO == cono).ToListAsync();
                var dtoList = mapper.Map<List<CategoryDto>>(res);

                return new Result<List<CategoryDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetList=>Exception:" + ex);
                return ResultFactory.Exception<List<CategoryDto>>(ex);
            }
        }

        /// <summary>
        /// 获取分类树结构
        /// </summary>
        /// <returns></returns>
        public async Task<Result<List<CategoryTree>>> GetCategoryTreeListAsync()
        {
            var result = new Result<List<CategoryTree>>();
            try
            {
                var cono = httpUserContext.Context.UserInfo.CompanyID;
                var res = await repository.GetAll().Where(m => m.CONO == cono).ToListAsync();
                var dtoList = mapper.Map<List<CategoryDto>>(res);

                var treeNodes = new List<CategoryTree>();

                BindCategoryTree(dtoList, null, Guid.Empty.ToString(), treeNodes);

                result.data = treeNodes;
            }
            catch (Exception ex)
            {
                result.code = (int)ApiEnum.Error;
                result.msg = ApiEnum.Error.GetEnumText();
                Log.Error("CategoryService=>GetCategoryTreeListAsync=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
            }

            result.result = true;
            result.code = (int)ApiEnum.Success;

            return result;
        }

        public void BindCategoryTree(List<CategoryDto> categoryList, CategoryTree parentNode, string parentID, List<CategoryTree> treeNodes)
        {
            var parentList = categoryList.Where(x => x.ParentID.ToString() == parentID).OrderBy(x => int.Parse(x.TreeCode)).ToList();

            foreach (var category in parentList)
            {
                CategoryTree tree = new CategoryTree();
                tree.id = category.ID.ToString();
                tree.treeName = category.Caption;
                tree.pid = category.ParentID?.ToString();
                tree.sort = category.TreeCode;
                //递归性质，函数内调用自身函数
                BindCategoryTree(categoryList, tree, tree.id.ToString(), treeNodes);
                //递归结束的终点条件
                if (parentNode == null)
                {
                    treeNodes.Add(tree);
                }
                else
                {
                    parentNode.treeList.Add(tree);
                }
            }
        }

        /// <summary>
        /// 加载右侧模块
        /// </summary>
        /// <param name="categoryParam"></param>
        /// <returns></returns>
        public async Task<Result<List<ModuleDto>>> GetModuleAsync(PagingInfo paging, CategoryParam categoryParam)
        {
            try
            {
                var categoryIds = new List<string>();
                var cono = httpUserContext.Context.UserInfo.CompanyID;
                // 分类ID 没有的情况
                if (categoryParam.ID == Guid.Empty)
                {
                    var id = _httpContext.HttpContext.Request.Query["ID"];
                    if (string.IsNullOrWhiteSpace(id))
                    {
                        categoryIds = await repository.GetAll().Where(m => m.CONO == cono).Select(m => m.ID.ToString()).ToListAsync();
                    }
                }
                else
                {
                    categoryIds = await repository.GetAll().Where(x => x.ParentID == categoryParam.ID).Select(m => m.ID.ToString()).ToListAsync();
                    categoryIds.Add(categoryParam.ID.ToString());
                }

                var categoryIdList = string.Join("','", categoryIds);
                paging.SqlWhere.Append($" and CategoryID in ('{categoryIdList}') ");

                var res = await _moduleRepository.GetPagesAsync(paging);

                var dtoList = mapper.Map<List<ModuleDto>>(res.data.Items);

                return ResultFactory.Success(dtoList, res.data.TotalItems);

            }
            catch (Exception ex)
            {
                Log.Error("CategoryService=>GetModuleAsync=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
                return ResultFactory.Error<List<ModuleDto>>();
            }
        }

        /// <summary>
        /// 删除API类别以及关联的子项
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        public Result<string> DelCategoryById(Guid id)
        {
            try
            {
                var res = repository.DelCategoryById(id); ;

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>DelCategoryById=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }
    }
}
					
					
					using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        /// <summary>
        /// 新增数据
        /// </summary>
        /// <param name="moduleDataItem"></param>
        /// <returns></returns>
        private async Task<ExpandoObject> ExecuteAppendData(ModuleDataDto moduleDataItem)
        {
            try
            {
                // 检查过滤参数
                CheckFilterParams(moduleDataItem);
                if (moduleDataItem.Primarykey.IsNullOrEmpty())
                {
                    moduleDataItem.ErrorMessageList.Add("导入数据需要主键，请配置主键");
                }

                // 如果有请求参数错误信息，就返回，不再执行数据查询
                if (moduleDataItem.ErrorMessageList.Count > 0)
                {
                    var filterErr = new ExpandoObject();
                    filterErr.AddObject("请求参数错误", moduleDataItem.ErrorMessageList);
                    return filterErr;
                }

                var listFilterParams = new List<List<FilterFieldParameter>>();
                var listFilterFieldValueMaps = moduleDataItem.ListFilterFieldValueMaps;
                if (listFilterFieldValueMaps == null)
                {
                    listFilterFieldValueMaps = new List<Dictionary<string, FilterFieldParam>>();
                    listFilterFieldValueMaps.Add(moduleDataItem.FilterFieldValueMaps);
                }

                foreach (var item in listFilterFieldValueMaps)
                {
                    listFilterParams.Add(mapper.Map<List<FilterFieldParameter>>(item.Values));
                }

                // 实现插入
                var resData = await dataQueryRepository.ExecuteBatchUpdateOrInsert(moduleDataItem.TableName,
                            moduleDataItem.Primarykey, moduleDataItem.IgnoreFields, listFilterParams.ToArray());

                var resExpandoObject = new ExpandoObject();
                resExpandoObject.AddObject("result", resData);
                return resExpandoObject;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>ExecuteAppendData=>Exception:" + ex);
                throw;
            }
        }

    }

}

			
					using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        private const string LogClassName = "DataQueryService";

        /// <summary>
        /// 过滤条件占位符
        /// </summary>
        private const string FilterPlaceholder = "[[Filter]]";

        #region 默认支持的返回字段命常量     

        /// <summary>
        /// 数据总条数
        /// </summary>
        private const string ConstReturn_RecordCount = "RecordCount";
        /// <summary>
        /// 本次返回的数据条数
        /// </summary>
        private const string ConstReturn_DataRecordCount = "DataRecordCount";
        /// <summary>
        /// 总页数
        /// </summary>
        private const string ConstReturn_PageCount = "PageCount";
        private const string ConstReturn_PageSize = "PageSize";
        private const string ConstReturn_PageIndex = "PageIndex";

        #endregion

        private readonly IMapper mapper;
        private readonly ICategoryRepository categoryRepository;
        private readonly IModuleRepository moduleRepository;
        private readonly IModuleDataRepository moduleDataRepository;
        private readonly IModuleFilterRepository moduleFilterRepository;
        private readonly IModuleFieldRepository moduleFieldRepository;
        private readonly IDataQueryRepository dataQueryRepository;
        public DataQueryService(IMapper _mapper,
            IModuleRepository _moduleRepository,
            IModuleDataRepository _moduleDataRepository,
            IModuleFilterRepository _moduleFilterRepository,
            IModuleFieldRepository _moduleFieldRepository,
            ICategoryRepository _categoryRepository,
            IDataQueryRepository _dataQueryRepository)
        {
            mapper = _mapper;
            moduleRepository = _moduleRepository;
            moduleDataRepository = _moduleDataRepository;
            moduleFilterRepository = _moduleFilterRepository;
            moduleFieldRepository = _moduleFieldRepository;
            dataQueryRepository = _dataQueryRepository;
            categoryRepository = _categoryRepository;
        }

        /// <summary>
        /// 执行数据查询
        /// </summary>
        /// <param name="dataQueryParam"></param>
        /// <returns></returns>
        public async Task<Result<ExpandoObject>> QueryData(DataQueryParam dataQueryParam)
        {
            try
            {
                // 获取module
                var moduleModel = (await moduleRepository.GetModelAsync(m => m.Code == dataQueryParam.ModuleCode)).data;
                ParamGuard.EnsureExist(moduleModel, $"接口代码:{dataQueryParam.ModuleCode}不存在");

                // 获取分类实体
                var categoryModel = (await categoryRepository.GetModelAsync(m => m.ID == moduleModel.CategoryID)).data;
                ParamGuard.EnsureExist(categoryModel, $"接口分类不存在");

                #region 接口配置数据获取

                var moduleModelDto = mapper.Map<ModuleDto>(moduleModel);
                // 获取module
                var moduleDataList = (await moduleDataRepository.GetListAsync(m => m.ModuleID == moduleModel.ID)).data;

                // 给接口查询列表赋值
                moduleModelDto.ModuleDataList = mapper.Map<List<ModuleDataDto>>(moduleDataList.OrderBy(m => m.OrderNo));

                var dataSetIds = moduleDataList.Select(m => m.DomainSetID).ToList();
                // 获取关联的查询参数
                var moduleFilterList = (await moduleFilterRepository.GetListAsync(m => m.DomainSetID != null && dataSetIds.Contains(m.DomainSetID.Value))).data;

                // 获取关联的输出参数
                var moduleFieldList = (await moduleFieldRepository.GetListAsync(m => m.DomainSetID != null && dataSetIds.Contains(m.DomainSetID.Value))).data;

                JToken moduleParamJson = null;
                var pageParam = new PageParam();
                // 请求参数  
                if (!(dataQueryParam.ModuleParam is null))
                {
                    // moduleParamJson = JObject.Parse(dataQueryParam.ModuleParam.ToString());       
                    moduleParamJson = JToken.Parse(dataQueryParam.ModuleParam.ToString());

                    if (moduleParamJson.Type == JTokenType.Object)
                    {
                        pageParam = moduleParamJson.ToObject<PageParam>();
                    }
                }
                // 给每个查询的 查询参数，输出参数赋值
                foreach (var moduleDataItem in moduleModelDto.ModuleDataList)
                {
                    // 临时写死
                    moduleDataItem.CONO = Guid.Parse("ab725f7b-ae70-4c01-a4ab-e1ceade972ac");// categoryModel.CONO;

                    // 请求参数，查询过滤字段相关处理    
                    moduleDataItem.ModuleFilterList = mapper.Map<List<ModuleFilterDto>>(moduleFilterList.Where(m => m.DomainSetID == moduleDataItem.DomainSetID));
                    if (moduleParamJson != null)
                    {
                        // 查询条件 key:Field, value :requestValue
                        MapFilterFieldValue(moduleDataItem, moduleParamJson);
                    }
                    // 输出字段，相关处理
                    moduleDataItem.ModuleFieldList = mapper.Map<List<ModuleFieldDto>>(moduleFieldList.Where(m => m.DomainSetID == moduleDataItem.DomainSetID).OrderBy(m => m.OrderNo));
                    MapOutCodeField(moduleDataItem);
                }

                #endregion

                var resObj = new ExpandoObject();

                foreach (var item in moduleModelDto.ModuleDataList)
                {
                    // 检查接口配置
                    CheckModuleParams(item);

                    // 如果有过滤参数错误，返回错误信息，不执行查询了
                    if (item.ErrorMessageList != null && item.ErrorMessageList.Count > 0)
                    {
                        resObj.AddObject(item.DomainSetName, item.ErrorMessageList);
                        continue;
                    }

                    switch (item.OpenMode)
                    {
                        case ConstOpenModes.SQL:
                            {
                                var dataSetObj = await QuerySql(item, pageParam);
                                resObj.AddObject(item.DomainSetName, dataSetObj);
                            }
                            break;
                        case ConstOpenModes.OpenTable:
                            {
                                var dataSetObj = await QueryTable(item, pageParam);
                                resObj.AddObject(item.DomainSetName, dataSetObj);
                            }
                            break;
                        case ConstOpenModes.StoredProcedure:
                            {
                                var dataSetObj = await QueryStoredProcedure(item);
                                resObj.AddObject(item.DomainSetName, dataSetObj);
                            }
                            break;
                        case ConstOpenModes.StoredProcedureNone:
                            {
                                var dataSetObj = await QueryStoredProcedureNone(item);
                                resObj.AddObject(item.DomainSetName, dataSetObj);
                            }
                            break;
                        case ConstOpenModes.AppendData:
                            {
                                var dataSetObj = await ExecuteAppendData(item);
                                resObj.AddObject(item.DomainSetName, dataSetObj);
                            }
                            break;
                        default:
                            throw new NotSupportedException($"不支持的打开模式 '{item.OpenMode}'");
                    }
                }


                return ResultFactory.Success(resObj);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>QueryData=>Exception:" + ex);
                return ResultFactory.Exception<ExpandoObject>(ex);
            }
        }

        /// <summary>
        /// 检查过滤参数
        /// </summary>
        /// <param name="moduleDataItem"></param>
        private void CheckFilterParams(ModuleDataDto moduleDataItem)
        {
            if (moduleDataItem.ErrorMessageList == null) moduleDataItem.ErrorMessageList = new List<string>();

            // JObject 形式参数输入
            if (moduleDataItem.FilterFieldValueMaps == null)
                moduleDataItem.FilterFieldValueMaps = new Dictionary<string, FilterFieldParam>();

            // JArray 形式参数输入
            if (moduleDataItem.ListFilterFieldValueMaps != null)
            {
                foreach (var filterFieldValueMaps in moduleDataItem.ListFilterFieldValueMaps)
                {
                    CheckFilterPerParam(moduleDataItem, filterFieldValueMaps);
                }
            }
            else
            {
                CheckFilterPerParam(moduleDataItem, moduleDataItem.FilterFieldValueMaps);
            }
        }

        private void CheckFilterPerParam(ModuleDataDto moduleDataItem, Dictionary<string, FilterFieldParam> filterFieldValueMaps)
        {
            foreach (var filterItem in moduleDataItem.ModuleFilterList)
            {
                // 检查比较运算符是否支持
                if (!filterItem.DefaultCompare.IsNullOrEmpty() && !ConstCompareOperators.SuppotsList.Contains(filterItem.DefaultCompare))
                {
                    moduleDataItem.ErrorMessageList.Add($"过滤参数 {filterItem.Name} 不支持比较运算符'{filterItem.DefaultCompare}'");
                }
                FilterFieldParam filterParam = null;
                // 参数未提供
                if (filterFieldValueMaps.ContainsKey(filterItem.Field))
                {
                    filterParam = filterFieldValueMaps[filterItem.Field];
                }

                // 检查 是否必要参数
                if (filterItem.bMust.HasValue && filterItem.bMust.Value &&
                (filterParam == null || !filterParam.IsExists)) // 请求时没有提供对应参数
                {
                    moduleDataItem.ErrorMessageList.Add($"过滤参数 {filterItem.Name} 为必要参数");
                    continue;
                }
                // 检查 是否必须有值
                if (filterItem.bValue.HasValue && filterItem.bValue.Value
                        && (filterParam == null || filterParam.Value == null || string.IsNullOrEmpty(filterParam.Value.ToString())))
                {
                    moduleDataItem.ErrorMessageList.Add($"过滤参数 {filterItem.Name} 必须有值");
                    continue;
                }
            }
        }

        /// <summary>
        /// 检查接口设置
        /// </summary>
        /// <param name="moduleDataItem"></param>
        private void CheckModuleParams(ModuleDataDto moduleDataItem)
        {
            if (moduleDataItem.ErrorMessageList == null) moduleDataItem.ErrorMessageList = new List<string>();

            switch (moduleDataItem.OpenMode)
            {
                case ConstOpenModes.SQL:
                    if (moduleDataItem.SQL.IsNullOrEmpty())
                    {
                        moduleDataItem.ErrorMessageList.Add("未配置查询语句");
                    }
                    else
                    {
                        // 如果语句中 配置了 [[Filter]]，但是没有过滤参数
                        if (moduleDataItem.SQL.Contains(FilterPlaceholder) && moduleDataItem.ModuleFilterList.Count == 0)
                        {
                            moduleDataItem.ErrorMessageList.Add("未配置过滤参数");
                        }
                        // 没有 [[Filter]] 但是 SQL 语句是  Where 结尾 或者 提供了过滤参数
                        if (!moduleDataItem.SQL.Contains(FilterPlaceholder)
                            && (moduleDataItem.SQL.ToUpper().TrimEnd().EndsWith("WHERE")
                                || moduleDataItem.ModuleFilterList.Count > 0))
                        {
                            moduleDataItem.ErrorMessageList.Add($"SQL语句带条件标准格式为：'SELECT * FROM TABLE WHERE {FilterPlaceholder}'");
                        }
                    }
                    break;
                case ConstOpenModes.OpenTable:
                case ConstOpenModes.StoredProcedure:
                case ConstOpenModes.StoredProcedureNone:
                    if (moduleDataItem.TableName.IsNullOrEmpty())
                    {
                        moduleDataItem.ErrorMessageList.Add("未配置表名称或者存储过程名称");
                    }
                    break;
            }

        }

        /// <summary>
        /// 数据集转换成动态对象
        /// </summary>
        /// <param name="pageParam">分页参数</param>
        /// <param name="resDataSet">数据集</param>
        /// <param name="moduleDataItem">查询配置，包含输出参数映射</param>
        /// <returns></returns>
        private ExpandoObject GetDataSetExpandoObject(PageParam pageParam, DataSet resDataSet, ModuleDataDto moduleDataItem)
        {
            if (moduleDataItem.DomainJsonFormat.IsNullOrEmpty())
            {
                moduleDataItem.DomainJsonFormat = ConstDataJsonFormats.DefaultDataJsonFormat;
            }
            // pageParam== null 时不做分页处理，比如存储过程
            if (pageParam != null)
            {
                // 分页参数不生效的时候，moduleDataItem.PageSize > 0 有效
                if (moduleDataItem.PageSize > 0 && pageParam.PageSize < 1)
                {
                    pageParam.PageSize = moduleDataItem.PageSize.Value;
                }
            }
            // 避免后面的非空检查
            if (pageParam == null) pageParam = new PageParam();

            var dataSetExpandoObject = new ExpandoObject();
            var recordCount = -1;
            // PageRefresh 为 true 的时候，需要返回数据总条数
            if (pageParam.PageRefresh.HasValue && pageParam.PageRefresh.Value)
            {
                var dtRecordCount = resDataSet.Tables[1];
                resDataSet.Tables.RemoveAt(1);
                recordCount = GetRecordCount(dtRecordCount);

                dataSetExpandoObject = DataSetToExpandoObject(resDataSet, pageParam, moduleDataItem.OutCodeFieldMaps, moduleDataItem.DomainJsonFormat);
                dataSetExpandoObject.AddObject(ConstReturn_RecordCount, recordCount);
            }
            else
            {
                dataSetExpandoObject = DataSetToExpandoObject(resDataSet, pageParam, moduleDataItem.OutCodeFieldMaps, moduleDataItem.DomainJsonFormat);
            }
            // 返回结果为 JsonArray 时分页相关的内容才返回
            if (moduleDataItem.DomainJsonFormat == ConstDataJsonFormats.JsonArray)
            {
                dataSetExpandoObject.AddObject(ConstReturn_DataRecordCount, GetDataRecordCount(resDataSet));
                // 如果 pageSize > 0  做了分页处理，需要返回 PageCount
                if (pageParam != null && pageParam.PageSize > 0)
                {
                    dataSetExpandoObject.AddObject(ConstReturn_PageCount, GetPageCount(recordCount, pageParam.PageSize));
                    dataSetExpandoObject.AddObject(ConstReturn_PageSize, pageParam.PageSize);
                    dataSetExpandoObject.AddObject(ConstReturn_PageIndex, pageParam.PageIndex);
                }
            }
            return dataSetExpandoObject;
        }
        private int GetPageCount(int recordCount, int pageSize)
        {
            var pageCount = recordCount / pageSize;
            var mod = recordCount % pageSize;
            if (mod > 0)
            {
                pageCount += 1;
            }
            return pageCount;
        }

        private string GetPageSql(PageParam pageParam, string sbSql, string primarykey, string orderByField)
        {
            pageParam.PageIndex = pageParam.PageIndex < 1 ? 1 : pageParam.PageIndex;

            pageParam.EndIndex = pageParam.PageSize * pageParam.PageIndex;
            pageParam.BenginIndex = pageParam.PageSize * (pageParam.PageIndex - 1);

            // 没有主键
            // if (primarykey.IsNullOrEmpty() && orderByField.IsNullOrEmpty())
            // {
            var pageSql = $@"SELECT * INTO #TempT FROM ({sbSql}) A ;
                            SELECT TOP {pageParam.EndIndex} * FROM #TempT ;
                            Drop TABLE #TempT; ";
            pageParam.SkipIndex = pageParam.BenginIndex;
            return pageSql;
            // }

            // // 主键和排序字段都有
            // var pageSql2 = $@"SELECT w2.n, w1.* FROM  ({sbSql}) w1,
            //                     (
            //                         SELECT TOP {pageParam.EndIndex} row_number() OVER (ORDER BY {orderByField} DESC) n, 
            //                         * FROM ({sbSql}) a
            //                     ) w2 WHERE w1.{primarykey} = w2.{primarykey} AND w2.n > {pageParam.BenginIndex} ORDER BY w2.n ASC; ";
            // return pageSql2;

        }
        private string GetPageSql(PageParam pageParam, string sbSql, string primarykey)
        {
            pageParam.PageIndex = pageParam.PageIndex < 1 ? 1 : pageParam.PageIndex;

            var endIndex = pageParam.PageSize * pageParam.PageIndex;
            var benginIndex = pageParam.PageSize * (pageParam.PageIndex - 1);

            var pageSql = $@"SELECT * INTO #TempTTT FROM ({sbSql}) AAA ;
                            SELECT * FROM #TempTTT 
                            WHERE {primarykey} in 
                                (
                                    SELECT top {pageParam.PageSize} {primarykey} FROM 
                                    (
                                        SELECT top {endIndex} {primarykey} FROM #TempTTT
                                    ) BBB
                                );
                            Drop TABLE #TempTTT;       
                            ";
            return pageSql;
        }

        private int GetDataRecordCount(DataSet resDataSet)
        {
            var records = 0;
            foreach (DataTable item in resDataSet.Tables)
            {
                records += item.Rows.Count;
            }
            return records;
        }

        private int GetRecordCount(DataTable dtRecordCount)
        {
            if (dtRecordCount.Columns.Count == 1 && dtRecordCount.Rows.Count == 1)
            {
                var countObj = dtRecordCount.Rows[0][0];
                return (int)countObj;
            }
            return -1;
        }

        /// <summary>
        /// DataSet 转 ExpandoObject
        /// </summary>
        /// <param name="dataSet">dataSet</param>
        /// <param name="skipIndex">存在分页情况的时候跳过数据</param>
        /// <param name="codeFieldMaps"></param>
        /// <param name="dataJsonFormat"></param>
        /// <param name="defaultPageSize">返回数据大小</param>
        /// <returns>ExpandoObject</returns>
        private ExpandoObject DataSetToExpandoObject(DataSet dataSet, PageParam pageParam, Dictionary<string, string> codeFieldMaps
            , string dataJsonFormat)
        {
            var dataSetObj = new ExpandoObject();

            switch (dataJsonFormat)
            {
                // 返回JSON数组
                case ConstDataJsonFormats.JsonArray:
                    for (int i = 0; i < dataSet.Tables.Count; i++)
                    {
                        DataTable dataTable = dataSet.Tables[i];
                        if (pageParam.SkipIndex > 0 || pageParam.PageSize > 0)
                        {
                            var dataRowList = new List<DataRow>();
                            var pageSize = pageParam.PageSize > 0 ? pageParam.PageSize : dataRowList.Count - pageParam.SkipIndex;

                            while (dataRowList.Count < pageSize && dataTable.Rows.Count > dataRowList.Count + pageParam.SkipIndex)
                            {
                                dataRowList.Add(dataTable.Rows[dataRowList.Count + pageParam.SkipIndex]);
                            }
                            var dataTableObj = DataRowsToExpandoObjectList(dataRowList, codeFieldMaps);
                            dataSetObj.AddObject($"data{i}", dataTableObj);
                        }
                        else
                        {
                            var dataTableObj = DataRowsToExpandoObjectList(dataTable.Rows, codeFieldMaps);
                            dataSetObj.AddObject($"data{i}", dataTableObj);
                        }
                    }
                    break;
                // 返回单个对象
                case ConstDataJsonFormats.JsonObject:
                    for (int i = 0; i < dataSet.Tables.Count; i++)
                    {
                        var dataTable = dataSet.Tables[i];
                        if (dataTable.Rows.Count > 0)
                        {
                            var dataRowObj = DataRowToExpandoObject(dataTable.Rows[0], codeFieldMaps);
                            dataSetObj.AddObject($"data{i}", dataRowObj);
                        }
                        else
                        {
                            dataSetObj.AddObject($"data{i}", null);
                        }
                    }
                    break;
                case ConstDataJsonFormats.Base64:
                    break;

            }

            return dataSetObj;
        }
        private ExpandoObject DataRowToExpandoObject(DataRow rowItem, Dictionary<string, string> codeFieldMaps)
        {
            var dynamicObj = new ExpandoObject();
            foreach (var fieldItem in codeFieldMaps)
            {
                var fieldValue = rowItem.Field<object>(fieldItem.Value);

                // 字段的数据类型 ？？？

                dynamicObj.AddObject(fieldItem.Key, fieldValue);
            }
            return dynamicObj;
        }
        /// <summary>
        /// DataTable 转为动态对象列表
        /// </summary>
        /// <param name="dataTable">dataTable</param>
        /// <param name="codeFieldMaps">输出别名与字段的映射</param>
        /// <param name="defaultPageSize">默认返回大小，大于0是有效</param>
        /// <returns>List<ExpandoObject></returns>
        private List<ExpandoObject> DataTableToExpandoObjectList(DataTable dataTable, Dictionary<string, string> codeFieldMaps, int defaultPageSize)
        {
            var listObj = new List<ExpandoObject>();
            var count = 0;
            foreach (DataRow rowItem in dataTable.Rows)
            {
                var dynamicObj = new ExpandoObject();
                foreach (var fieldItem in codeFieldMaps)
                {
                    var fieldValue = rowItem.Field<object>(fieldItem.Value);
                    // 字段的数据类型 ？？？
                    dynamicObj.AddObject(fieldItem.Key, fieldValue);
                }
                listObj.Add(dynamicObj);
                if (defaultPageSize > 0)
                {
                    count++;
                    if (count > defaultPageSize)
                    {
                        break;
                    }
                }
            }
            return listObj;
        }

        /// <summary>
        /// dataRows 转为动态对象列表
        /// </summary>
        /// <param name="dataRows">dataRows</param>
        /// <param name="codeFieldMaps">输出别名与字段的映射</param>
        /// <param name="defaultPageSize">默认返回大小，大于0是有效</param>
        /// <returns>List<ExpandoObject></returns>
        private List<ExpandoObject> DataRowsToExpandoObjectList(IEnumerable dataRows, Dictionary<string, string> codeFieldMaps)
        {
            var listObj = new List<ExpandoObject>();
            foreach (DataRow rowItem in dataRows)
            {
                var dynamicObj = new ExpandoObject();
                foreach (var fieldItem in codeFieldMaps)
                {
                    var fieldValue = rowItem.Field<object>(fieldItem.Value);
                    dynamicObj.AddObject(fieldItem.Key, fieldValue);
                }
                listObj.Add(dynamicObj);
            }
            return listObj;
        }

    }

}

					
					using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        /// <summary>
        /// 请求字段与值得匹配
        /// </summary>
        /// <param name="moduleDataItem"></param>
        /// <param name="moduleParamJToken"></param>
        private void MapFilterFieldValue(ModuleDataDto moduleDataItem, JToken moduleParamJToken)
        {
            // 插入数据的时候支持数组形式的请求参数
            if (moduleParamJToken.Type == JTokenType.Array)
            {
                moduleDataItem.ListFilterFieldValueMaps = new List<Dictionary<string, FilterFieldParam>>();
                var moduleParamJarray = (JArray)moduleParamJToken;
                foreach (var itemJToken in moduleParamJarray)
                {
                    var itemFilterFieldValueMaps = new Dictionary<string, FilterFieldParam>();
                    moduleDataItem.ListFilterFieldValueMaps.Add(itemFilterFieldValueMaps);
                    foreach (var filterItem in moduleDataItem.ModuleFilterList)
                    {
                        filterItem.CONO = moduleDataItem.CONO;
                        // 从请求参数中取出 对应参数的值
                        SetFilterParam(itemJToken, itemFilterFieldValueMaps, filterItem);
                    }
                }
                return;
            }

            moduleDataItem.FilterFieldValueMaps = new Dictionary<string, FilterFieldParam>();
            foreach (var filterItem in moduleDataItem.ModuleFilterList)
            {
                filterItem.CONO = moduleDataItem.CONO;
                // 从请求参数中取出 对应参数的值
                SetFilterParam(moduleParamJToken, moduleDataItem.FilterFieldValueMaps, filterItem);
            }
        }

        /// <summary>
        /// 设置过滤参数
        /// 从输入取值，系统默认值，配置的默认值等等
        /// </summary>
        /// <param name="itemJToken"></param>
        /// <param name="itemFilterFieldValueMaps"></param>
        /// <param name="filterItem"></param>
        private void SetFilterParam(JToken itemJToken, Dictionary<string, FilterFieldParam> itemFilterFieldValueMaps
                                    , ModuleFilterDto filterItem)
        {
            // 字段名称重复提供
            if (itemFilterFieldValueMaps.ContainsKey(filterItem.Field)) return;

            var filterParam = new FilterFieldParam()
            {
                Code = filterItem.Name,
                Field = filterItem.Field,
                IsOutput = filterItem.bOutParam.HasValue ? filterItem.bOutParam.Value : false
            };

            // 先赋值为配置的默认值
            object reqVal = filterItem.DefaultValue;
            // 取值方式枚举
            var enumDefaultType = DefaultTypeEnums.JSONValue;
            if (!filterItem.DefaultType.IsNullOrEmpty())
            {
                if (int.TryParse(filterItem.DefaultType, out int val))
                {
                    enumDefaultType = (DefaultTypeEnums)val;
                }
            }
            // 根据设置的默认值取值方式 取值
            switch (enumDefaultType)
            {
                case DefaultTypeEnums.DefaultDateTime:
                    reqVal = DateTime.Now;
                    break;
                case DefaultTypeEnums.FixedParameter:
                    reqVal = GetFixedParameterValue(filterItem);
                    break;
                case DefaultTypeEnums.SystemDefaultValue:
                    reqVal = GetSystemDefaultValue(filterItem);
                    break;
                case DefaultTypeEnums.UserParamValue:
                    reqVal = GetUserParamValueValue(filterItem);
                    break;
                case DefaultTypeEnums.JSONValue:
                default:
                    reqVal = GetJSONValue(itemJToken, filterItem);
                    break;
            }

            // reqVal == null 说明没有提供参数
            filterParam.IsExists = reqVal != null;
            filterParam.Value = reqVal;
            itemFilterFieldValueMaps.Add(filterItem.Field, filterParam);
        }
        #region  根据配置取值
        /// <summary>
        /// 取用户参数信息
        /// 目前支持 CONO,从分类表取
        /// </summary>
        /// <param name="filterItem"></param>
        /// <returns></returns>
        private object GetUserParamValueValue(ModuleFilterDto filterItem)
        {
            if (filterItem.Field.ToUpper() == "CONO")
            {
                return filterItem.CONO;
            }
            return filterItem.DefaultValue;
        }
        /// <summary>
        /// 取请求参数中的值，没有值得话返回设置的默认值
        /// </summary>
        /// <param name="itemJToken"></param>
        /// <param name="filterItem"></param>
        /// <returns></returns>
        private object GetJSONValue(JToken itemJToken, ModuleFilterDto filterItem)
        {
            var jsonReqVal = itemJToken[filterItem.Name];
            // 如果请求参数有值，才覆盖默认值
            if (jsonReqVal != null)
            {
                switch (filterItem.DomainType.Trim())
                {
                    case DataTypeConstStr._bool:
                        break;
                    case DataTypeConstStr._date:
                        var valStr = jsonReqVal.ToString();
                        if (valStr.IsNullOrEmpty())
                        {
                            return null;
                        }
                        // if (DateTime.TryParse(valStr, out DateTime dateTime))
                        // {
                        //     jsonReqVal = dateTime;
                        // }
                        break;
                    default:
                        break;
                }
                return jsonReqVal;
            }
            return filterItem.DefaultValue;
        }

        private object GetSystemDefaultValue(ModuleFilterDto filterItem)
        {
            switch (filterItem.DomainType.Trim())
            {
                case DataTypeConstStr._bool:
                    return false;
                case DataTypeConstStr._guid:
                    // 字段名名称是 CONO 时不自动赋值，防止出现 公司区分错误
                    if (filterItem.Field.ToUpper() != "CONO")
                    {
                        return Guid.NewGuid();
                    }
                    break;
                default:
                    break;
            }
            return filterItem.DefaultValue;
        }

        /// <summary>
        /// 固定参数
        /// 取该字段设置的默认值
        /// </summary>
        /// <param name="filterItem"></param>
        /// <returns></returns>
        private object GetFixedParameterValue(ModuleFilterDto filterItem)
        {
            return filterItem.DefaultValue;
        }

        #endregion

        /// <summary>
        /// 输出字段与别名的匹配
        /// </summary>
        /// <param name="moduleDataItem"></param>
        private void MapOutCodeField(ModuleDataDto moduleDataItem)
        {
            // 输出字段, key:Field, value:code
            moduleDataItem.OutCodeFieldMaps = new Dictionary<string, string>();
            foreach (var item in moduleDataItem.ModuleFieldList)
            {
                var code = !string.IsNullOrWhiteSpace(item.JSONName) ? item.JSONName : item.Name;
                // 从请求参数中取出 对应参数的值
                if (!moduleDataItem.OutCodeFieldMaps.ContainsKey(code))
                {
                    moduleDataItem.OutCodeFieldMaps.Add(code, item.Name);
                }
            }

        }

        // 有待完善
        private object GetValueByDataType(string dataType, object value)
        {
            var res = value;
            dataType = dataType ?? string.Empty;
            switch (dataType.ToLower())
            {
                case DataTypeConstStr._int32:
                    break;
                case DataTypeConstStr._string:
                default:
                    res = value == null ? value : value.ToString();
                    break;
            }
            return res;
        }
    }

}
					
					using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        /// <summary>
        /// 执行查询，SQL形式
        /// </summary>
        /// <param name="moduleDataItem"></param>
        /// <param name="pageParam"></param>
        /// <returns></returns>
        private async Task<ExpandoObject> QuerySql(ModuleDataDto moduleDataItem, PageParam pageParam)
        {
            try
            {
                // 检查过滤参数
                CheckFilterParams(moduleDataItem);

                // 如果有请求参数错误信息，就返回，不再执行数据查询
                if (moduleDataItem.ErrorMessageList.Count > 0)
                {
                    var filterErr = new ExpandoObject();
                    filterErr.AddObject("请求参数错误", moduleDataItem.ErrorMessageList);
                    return filterErr;
                }

                // 查询条件 拼接
                var sbWhere = new StringBuilder();
                foreach (var filterItem in moduleDataItem.ModuleFilterList)
                {
                    if (sbWhere.Length > 0) { sbWhere.Append(" AND "); }
                    // 条件符号
                    var defaultCompareStr = filterItem.DefaultCompare.IsNullOrEmpty() ? ConstCompareOperators.DefaultOperator : filterItem.DefaultCompare;
                    sbWhere.Append($"{filterItem.Field}{defaultCompareStr}@{filterItem.Field}");
                }

                var sbSql = new StringBuilder();
                sbSql.Append(moduleDataItem.SQL);

                // 替换查询条件语句
                sbSql.Replace(FilterPlaceholder, sbWhere.ToString());

                // 分页或者查询数据总条数 需要这个变量
                var sqlQueryAll = sbSql.ToString();

                // 分页处理,如果 pageSize > 0  做分页处理
                if (pageParam.PageSize > 0)
                {
                    var orderByField = moduleDataItem.Primarykey;
                    var pageSql = GetPageSql(pageParam, sqlQueryAll, moduleDataItem.Primarykey, orderByField);

                    sbSql.Clear();
                    sbSql.Append(pageSql);
                }
                // PageRefresh 为 true 的时候，需要查询数据总条数
                if (pageParam.PageRefresh.HasValue && pageParam.PageRefresh.Value)
                {
                    // 查询数据总条数的语句
                    var recordCountStr = $";SELECT count(*) from ({sqlQueryAll}) t1";
                    sbSql.Append(recordCountStr);
                }

                var listFilterParam = mapper.Map<List<FilterFieldParameter>>(moduleDataItem.FilterFieldValueMaps.Values);
                // 执行查询
                var resDataSet = await dataQueryRepository.GetDataSetBySql(sbSql.ToString(), listFilterParam);

                var resDataSetExpandoObject = GetDataSetExpandoObject(pageParam, resDataSet, moduleDataItem);
                // 请求参数对象转换，转换成JSON对象形式
                var dataparamObj = new ExpandoObject();
                resDataSetExpandoObject.AddObject($"DataParamCount", listFilterParam.Count);
                foreach (var item in listFilterParam)
                {
                    dataparamObj.AddObject(item.Code, GetValueByDataType(null, item.Value));
                }
                resDataSetExpandoObject.AddObject($"DataParam", dataparamObj);
                return resDataSetExpandoObject;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>QuerySql=>Exception:" + ex);
                throw;
            }
        }


    }

}
					
					
					using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        /// <summary>
        /// 执行查询，存储过程形式
        /// </summary>
        /// <param name="moduleDataItem"></param>
        /// <returns></returns>
        private async Task<ExpandoObject> QueryStoredProcedure(ModuleDataDto moduleDataItem)
        {
            try
            {
                // 检查过滤参数
                CheckFilterParams(moduleDataItem);
                // 检查配置项
                if (moduleDataItem.TableName.IsNullOrEmpty())
                {
                    moduleDataItem.ErrorMessageList.Add("请配置有效的的存储过程名称");
                }

                // 如果有请求参数错误信息，就返回，不再执行数据查询
                if (moduleDataItem.ErrorMessageList.Count > 0)
                {
                    var filterErr = new ExpandoObject();
                    filterErr.AddObject("请求参数错误", moduleDataItem.ErrorMessageList);
                    return filterErr;
                }

                var listFilterParam = mapper.Map<List<FilterFieldParameter>>(moduleDataItem.FilterFieldValueMaps.Values);

                // 执行查询
                var resDataSet = await dataQueryRepository.GetDataSetByStoredProcedure(moduleDataItem.TableName, listFilterParam);

                var resDataSetExpandoObject = GetDataSetExpandoObject(null, resDataSet, moduleDataItem);

                resDataSetExpandoObject.AddObject($"DataParamCount", listFilterParam.Count);
                // 请求参数对象转换，转换成JSON对象形式
                var dataparamObj = new ExpandoObject();
                foreach (var item in listFilterParam)
                {
                    dataparamObj.AddObject(item.Code, GetValueByDataType(null, item.Value));
                }
                resDataSetExpandoObject.AddObject($"DataParam", dataparamObj);
                // dataSetObj.AddObject($"DataParamXXX", listFilterParam);

                return resDataSetExpandoObject;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>QueryStoredProcedure=>Exception:" + ex);
                throw;
            }
        }

    }

}

		using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        /// <summary>
        /// 执行查询，存储过程形式（不返回数据）
        /// </summary>
        /// <param name="moduleDataItem"></param>
        /// <returns></returns>
        private async Task<ExpandoObject> QueryStoredProcedureNone(ModuleDataDto moduleDataItem)
        {
            try
            {
                // 检查过滤参数
                CheckFilterParams(moduleDataItem);
                // 检查配置项
                if (moduleDataItem.TableName.IsNullOrEmpty())
                {
                    moduleDataItem.ErrorMessageList.Add("请配置有效的的存储过程名称");
                }

                // 如果有请求参数错误信息，就返回，不再执行数据查询
                if (moduleDataItem.ErrorMessageList.Count > 0)
                {
                    var filterErr = new ExpandoObject();
                    filterErr.AddObject("请求参数错误", moduleDataItem.ErrorMessageList);
                    return filterErr;
                }

                var listFilterParam = mapper.Map<List<FilterFieldParameter>>(moduleDataItem.FilterFieldValueMaps.Values);

                // 执行查询
                var resData = await dataQueryRepository.ExecuteStoredProcedure(moduleDataItem.TableName, listFilterParam);

                var resExpandoObject = new ExpandoObject();

                resExpandoObject.AddObject($"DataParamCount", listFilterParam.Count);
                // 请求参数对象转换，转换成JSON对象形式
                var dataparamObj = new ExpandoObject();
                foreach (var item in listFilterParam)
                {
                    dataparamObj.AddObject(item.Code, GetValueByDataType(null, item.Value));
                }
                resExpandoObject.AddObject($"DataParam", dataparamObj);

                return resExpandoObject;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>QueryStoredProcedureNone=>Exception:" + ex);
                throw;
            }
        }

    }

}

					
					
					using AutoMapper;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Domain;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public partial class DataQueryService : IDataQueryService
    {
        /// <summary>
        /// 执行查询，打开表形式
        /// </summary>
        /// <param name="moduleDataItem"></param>
        /// <param name="pageParam"></param>
        /// <returns></returns>
        private async Task<ExpandoObject> QueryTable(ModuleDataDto moduleDataItem, PageParam pageParam)
        {
            try
            {
                // 检查过滤参数
                CheckFilterParams(moduleDataItem);
                // 如果有请求参数错误信息，就返回，不再执行数据查询
                if (moduleDataItem.ErrorMessageList != null && moduleDataItem.ErrorMessageList.Count > 0)
                {
                    var filterErr = new ExpandoObject();
                    filterErr.AddObject("请求参数错误", moduleDataItem.ErrorMessageList);
                    return filterErr;
                }

                var sbFeildSql = new StringBuilder();
                foreach (var item in moduleDataItem.OutCodeFieldMaps)
                {
                    if (sbFeildSql.Length > 0) { sbFeildSql.Append(","); }
                    sbFeildSql.Append($"[{item.Value}]");
                }
                if (sbFeildSql.Length == 0)
                {
                    sbFeildSql.Append("*");
                }
                // 查询条件 拼接
                var sbWhere = new StringBuilder();
                foreach (var filterItem in moduleDataItem.ModuleFilterList)
                {
                    if (sbWhere.Length > 0) { sbWhere.Append(" AND "); }
                    // 条件符号
                    var defaultCompareStr = filterItem.DefaultCompare.IsNullOrEmpty() ? ConstCompareOperators.DefaultOperator : filterItem.DefaultCompare;
                    sbWhere.Append($"{filterItem.Field}{defaultCompareStr}@{filterItem.Field}");
                }
                if (sbWhere.Length > 0) { sbWhere.Insert(0, " WHERE "); }

                var sbSql = new StringBuilder();
                sbSql.Append($"SELECT {sbFeildSql} FROM {moduleDataItem.TableName} {sbWhere}");

                // 分页处理,如果 pageSize > 0  做分页处理
                if (pageParam.PageSize > 0)
                {
                    var primarykeyAlias = string.Empty;
                    var sqlQueryAll = $"SELECT {sbFeildSql} FROM {moduleDataItem.TableName} {sbWhere}";

                    var orderByField = moduleDataItem.Primarykey;
                    var primarykey = moduleDataItem.Primarykey;
                    // 如果主键不为空
                    if (!primarykey.IsNullOrEmpty())
                    {
                        primarykeyAlias = $"pKey_{moduleDataItem.Primarykey}";
                        sqlQueryAll = $"SELECT {sbFeildSql},{primarykey} as {primarykeyAlias} FROM {moduleDataItem.TableName} {sbWhere}";
                    }

                    var pageSql = GetPageSql(pageParam, sqlQueryAll, primarykeyAlias, orderByField);
                    sbSql.Clear();
                    sbSql.Append(pageSql);
                }

                // PageRefresh 为 true 的时候，需要查询数据总条数
                if (pageParam.PageRefresh.HasValue && pageParam.PageRefresh.Value)
                {
                    // 查询数据总条数的语句
                    var recordCountStr = $";SELECT count(*) from {moduleDataItem.TableName} {sbWhere};";
                    sbSql.Append(recordCountStr);
                }

                var listFilterParam = mapper.Map<List<FilterFieldParameter>>(moduleDataItem.FilterFieldValueMaps.Values);
                // 执行查询
                var resDataSet = await dataQueryRepository.GetDataSetBySql(sbSql.ToString(), listFilterParam);

                var resDataSetExpandoObject = GetDataSetExpandoObject(pageParam, resDataSet, moduleDataItem);

                return resDataSetExpandoObject;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>QueryTable=>Exception:" + ex);
                throw;
            }
        }

    }

}
					
					
					using AutoMapper;
using PTS2.BaseService;
using PTS2.Common;
using PTS2.Domain;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{

    public class ModuleDataService : IModuleDataService
    {
        private const string LogClassName = "ModuleDataService";
        private readonly IMapper mapper;
        private readonly IModuleDataRepository repository;
        private readonly IDataQueryRepository dataQueryRepository;
        private readonly IModuleRepository moduleRepository;


        private readonly ICommonService _commonService;
        public ModuleDataService(IMapper _mapper,
         IModuleDataRepository moduleDataRepository,
         ICommonService commonService,
         IDataQueryRepository _dataQueryRepository,
         IModuleRepository _moduleRepository)
        {
            mapper = _mapper;
            repository = moduleDataRepository;
            dataQueryRepository = _dataQueryRepository;
            _commonService = commonService;
            moduleRepository = _moduleRepository;
        }

        public async Task<Result<ModuleDataDto>> Create(ModuleDataParam moduleDataParam)
        {
            try
            {
                #region 参数检查
                var reqParam = moduleDataParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.ModuleID, nameof(reqParam.ModuleID));
                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainSetName, "数据集名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.OpenMode, "打开方式");
                ParamGuard.EnsureSupports(reqParam.OpenMode, nameof(reqParam.OpenMode), ConstOpenModes.SupportsList);
                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainJsonFormat, "Json数据格式");
                ParamGuard.EnsureSupports(reqParam.DomainJsonFormat, nameof(reqParam.DomainJsonFormat), ConstDataJsonFormats.SupportsList);

                ParamGuard.ValidateLength(reqParam.DomainSetName, "数据集名称", 50);
                ParamGuard.ValidateLength(reqParam.OpenMode, "打开方式", 20);
                ParamGuard.ValidateLength(reqParam.DomainJsonFormat, "JSON数据格式", 20);
                ParamGuard.ValidateLength(reqParam.TableName, "表名", 50);
                ParamGuard.ValidateLength(reqParam.Primarykey, "主键", 50);
                ParamGuard.ValidateLength(reqParam.SQL, "SQL", 1000);

                // ModuleID 需要有效
                var existModel = (await moduleRepository.GetModelAsync(m => m.ID == reqParam.ModuleID.Value)).data;
                ParamGuard.EnsureExist(existModel, $"ModuleID:{reqParam.ModuleID}不存在");
                // DataSetName 重复检查
                var notExistModel = (await repository.GetModelAsync(m => m.DomainSetName == reqParam.DomainSetName
                                    && m.ModuleID == reqParam.ModuleID)).data;
                ParamGuard.EnsureNotExist(notExistModel, $"数据集名称:{reqParam.DomainSetName}已经存在");
                #endregion 

                var model = mapper.Map<DataApi_ModuleData>(moduleDataParam);
                model.DomainSetID = Guid.NewGuid();
                var maxOrderNo = _commonService.GetTableMaxField("DataApi_ModuleData", "OrderNo", $"ModuleID='{moduleDataParam.ModuleID}'");
                model.OrderNo = maxOrderNo.data;

                var res = await repository.AddAsync(model);

                var dtoModel = mapper.Map<ModuleDataDto>(res.data);

                return ResultFactory.Success(dtoModel);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Create=>Exception:" + ex);
                return ResultFactory.Exception<ModuleDataDto>(ex);
            }
        }

        public async Task<Result<ModuleDataDto>> Get(Guid dataSetID)
        {
            try
            {
                var res = await repository.GetModelAsync(m => m.DomainSetID == dataSetID);

                var dtoModel = mapper.Map<ModuleDataDto>(res.data);

                return new Result<ModuleDataDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Get=>Exception:" + ex);
                return ResultFactory.Exception<ModuleDataDto>(ex);
            }
        }

        /// <summary>
        /// 获取表的字段列表
        /// </summary>
        /// <param name="dataSetId"></param>
        /// <returns></returns>
        public async Task<Result<List<ModuleFieldPlainDto>>> GetTableFieldList(Guid dataSetID)
        {
            try
            {
                var res = await repository.GetModelAsync(m => m.DomainSetID == dataSetID);
                if (!res.IsHandelSuccess())
                {
                    return ResultFactory.Error<List<ModuleFieldPlainDto>>(res.msg);
                }
                var model = res.data;
                #region 参数检查                    
                if (model == null)
                {
                    return ResultFactory.Error<List<ModuleFieldPlainDto>>("未找到查询配置");
                }
                if (model.OpenMode != ConstOpenModes.OpenTable)
                {
                    return ResultFactory.Error<List<ModuleFieldPlainDto>>("当前查询不是打开表模式");
                }
                if (model.TableName.IsNullOrEmpty())
                {
                    return ResultFactory.Error<List<ModuleFieldPlainDto>>("未找配置表名");
                }
                #endregion

                var resData = await dataQueryRepository.GetTableColumn<INFORMATION_SCHEMA_Column>(model.TableName);

                var resDto = mapper.Map<List<ModuleFieldPlainDto>>(resData);

                return ResultFactory.Success(resDto);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetTableFieldList=>Exception:" + ex);
                return ResultFactory.Exception<List<ModuleFieldPlainDto>>(ex);
            }
        }

        public async Task<Result<List<ModuleDataDto>>> GetListByModuleID(Guid moduleID)
        {
            try
            {
                var res = await repository.GetListAsync(m => m.ModuleID == moduleID);

                var dtoList = mapper.Map<List<ModuleDataDto>>(res.data);

                return new Result<List<ModuleDataDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetListByModuleID=>Exception:" + ex);
                return ResultFactory.Exception<List<ModuleDataDto>>(ex);
            }
        }

        public async Task<Result<List<ModuleDataDto>>> GetList()
        {
            try
            {
                var res = await repository.GetListAsync();

                var dtoList = mapper.Map<List<ModuleDataDto>>(res.data);

                return new Result<List<ModuleDataDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetList=>Exception:" + ex);
                return ResultFactory.Exception<List<ModuleDataDto>>(ex);
            }
        }

        public async Task<Result<ModuleDataDto>> Update(ModuleDataParam moduleDataParam)
        {
            try
            {

                var model = (await repository.GetModelAsync(m => m.DomainSetID == moduleDataParam.DomainSetID)).data;

                #region 参数检查
                var reqParam = moduleDataParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.ModuleID, nameof(reqParam.ModuleID));
                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainSetName, "数据集名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.OpenMode, "打开方式");
                ParamGuard.EnsureSupports(reqParam.OpenMode, nameof(reqParam.OpenMode), ConstOpenModes.SupportsList);
                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainJsonFormat, "Json数据格式");
                ParamGuard.EnsureSupports(reqParam.DomainJsonFormat, nameof(reqParam.DomainJsonFormat), ConstDataJsonFormats.SupportsList);

                ParamGuard.ValidateLength(reqParam.DomainSetName, "数据集名称", 50);
                ParamGuard.ValidateLength(reqParam.OpenMode, "打开方式", 20);
                ParamGuard.ValidateLength(reqParam.DomainJsonFormat, "JSON数据格式", 20);
                ParamGuard.ValidateLength(reqParam.TableName, "表名", 50);
                ParamGuard.ValidateLength(reqParam.Primarykey, "主键", 50);
                ParamGuard.ValidateLength(reqParam.SQL, "SQL", 1000);

                // ModuleID 需要有效
                var existModel = (await moduleRepository.GetModelAsync(m => m.ID == reqParam.ModuleID.Value)).data;
                ParamGuard.EnsureExist(existModel, $"ModuleID:{reqParam.ModuleID}不存在");
                // DataSetName 重复检查
                if (reqParam.DomainSetName.Replace(" ", "") != model.DomainSetName.Replace(" ", ""))
                {
                    var notExistModel = (await repository.GetModelAsync(m => m.DomainSetName == reqParam.DomainSetName
                                        && m.ModuleID == reqParam.ModuleID)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"数据集名称:{reqParam.DomainSetName}已经存在");
                }
                #endregion 

                model.SQL = moduleDataParam.SQL;
                model.OpenMode = moduleDataParam.OpenMode;
                model.DomainSetName = moduleDataParam.DomainSetName;
                model.TableName = moduleDataParam.TableName;
                model.PageSize = moduleDataParam.PageSize;
                model.DomainJsonFormat = moduleDataParam.DomainJsonFormat;
                model.Primarykey = moduleDataParam.Primarykey;
                model.IgnoreFields = moduleDataParam.IgnoreFields;

                // ……

                await repository.UpdateAsync(model);

                var dtoModel = mapper.Map<ModuleDataDto>(model);

                return new Result<ModuleDataDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Update=>Error:" + ex);
                return ResultFactory.Exception<ModuleDataDto>(ex);
            }
        }

        public async Task<Result<string>> Delete(Guid dataSetID)
        {
            try
            {
                var res = await repository.DeleteAsync(m => m.DomainSetID == dataSetID);

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Delete=>Error:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }

        public async Task<Result<List<string>>> GetOpenModeList()
        {
            try
            {
                var list = ConstOpenModes.SupportsList;

                return await Task.FromResult(new Result<List<string>>()
                {
                    data = list
                });
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetOpenModeList=>Error:" + ex);
                return ResultFactory.Exception<List<string>>(ex);
            }
        }
        public async Task<Result<List<string>>> GetDataJsonFormat()
        {
            try
            {
                var list = ConstDataJsonFormats.SupportsList;
                return await Task.FromResult(new Result<List<string>>()
                {
                    data = list
                });
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetDataJsonFormat=>Error:" + ex);
                return ResultFactory.Exception<List<string>>(ex);
            }
        }

        /// <summary>
        /// 获取API查询定义列表
        /// </summary>
        /// <param name="paging">分页</param>
        /// <param name="moduleID">模块ID</param>
        /// <returns></returns>
        public async Task<Result<List<ModuleDataDto>>> GetListAsync(PagingInfo paging, Guid moduleID)
        {
            var result = new Result<List<ModuleDataDto>>();
            try
            {
                paging.SqlWhere.Append($" and ModuleID = '{moduleID}' ");
                paging.OrderByList.Add("OrderNo", "ASC");
                var res = await repository.GetPagesAsync(paging);
                result.data = mapper.Map<List<ModuleDataDto>>(res.data.Items);
                result.count = res.data.TotalItems;

            }
            catch (Exception ex)
            {
                result.code = (int)ApiEnum.Error;
                result.msg = ApiEnum.Error.GetEnumText();
                Log.Error($"{LogClassName}=>GetListAsync=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
            }

            result.result = true;
            result.code = (int)ApiEnum.Success;

            return result;
        }

        /// <summary>
        /// 删除API查询定义
        /// </summary>
        /// <param name="Ids">数据集ID</param>
        /// <param name="mId">模块ID</param>
        /// <returns></returns>
        public Result<string> DelModuleDataByIds(List<string> Ids, string mId)
        {
            try
            {
                var res = repository.DelModuleDataByIds(Ids, mId); ;

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>DelModuleDataByIds=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }
    }
}
					
					
					
					using AutoMapper;
using PTS2.BaseService;
using PTS2.Common;
using PTS2.Domain;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{
    public class ModuleFieldService : IModuleFieldService
    {
        private const string LogClassName = "ModuleFieldService";
        private readonly IMapper mapper;
        private readonly IModuleFieldRepository repository;
        private readonly IModuleDataRepository moduleDataRepository;

        private readonly ICommonService _commonService;
        public ModuleFieldService(IMapper _mapper,
         IModuleFieldRepository moduleFieldRepository,
         ICommonService commonService,
         IModuleDataRepository _moduleDataRepository)
        {
            mapper = _mapper;
            repository = moduleFieldRepository;
            moduleDataRepository = _moduleDataRepository;
            _commonService = commonService;
        }

        public async Task<Result<ModuleFieldDto>> Create(ModuleFieldParam moduleDataParam)
        {
            try
            {
                #region 参数检查
                var reqParam = moduleDataParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Name, "字段名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.JSONName, "字段别名");

                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainSetID, nameof(reqParam.DomainSetID));
                ParamGuard.ValidateLength(reqParam.Name, "字段名称", 50);
                ParamGuard.ValidateLength(reqParam.JSONName, "字段别名", 50);
                ParamGuard.ValidateLength(reqParam.DefaultValue, "默认值", 50);
                ParamGuard.ValidateLength(reqParam.Caption, "说明", 50);

                var existModel = (await moduleDataRepository.GetModelAsync(m => m.DomainSetID == reqParam.DomainSetID.Value)).data;
                ParamGuard.EnsureExist(existModel, $"DataSetID:{reqParam.DomainSetID}不存在");
                var notExistModelJSONName = (await repository.GetModelAsync(m => m.DomainSetID == reqParam.DomainSetID.Value && m.JSONName == reqParam.JSONName)).data;
                ParamGuard.EnsureNotExist(notExistModelJSONName, $"字段别名:{reqParam.JSONName}已经存在");
                var notExistNameModelJSONName = (await repository.GetModelAsync(m => m.DomainSetID == reqParam.DomainSetID.Value && m.Name == reqParam.Name)).data;
                ParamGuard.EnsureNotExist(notExistNameModelJSONName, $"字段名称:{reqParam.Name}已经存在");
                reqParam.ModuleID = existModel.ModuleID;
                #endregion

                var model = mapper.Map<DataApi_ModuleField>(moduleDataParam);
                model.ID = Guid.NewGuid();
                var maxOrderNo = _commonService.GetTableMaxField("DataApi_ModuleField", "OrderNo", $"DataSetID='{moduleDataParam.DomainSetID}'");
                model.OrderNo = maxOrderNo.data;

                var res = await repository.AddAsync(model);
                if (!res.IsHandelSuccess())
                {
                    return ResultFactory.Error<ModuleFieldDto>(res.msg);
                }
                if (res.data == null)
                {
                    return ResultFactory.Success<ModuleFieldDto>("添加失败");
                }

                var dtoModel = mapper.Map<ModuleFieldDto>(res.data);
                return ResultFactory.Success(dtoModel);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Create=>Error:" + ex);
                return ResultFactory.Exception<ModuleFieldDto>(ex);
            }
        }

        public async Task<Result<string>> BatchCreate(Guid dataSetID, List<ModuleFieldParam> moduleDataParams)
        {
            try
            {
                var resModuleData = await moduleDataRepository.GetModelAsync(m => m.DomainSetID == dataSetID);
                if (!resModuleData.IsHandelSuccess())
                {
                    return ResultFactory.Error<string>("未找到查询配置");
                }

                var models = mapper.Map<List<DataApi_ModuleField>>(moduleDataParams);
                models.ForEach(m =>
                {
                    m.ID = Guid.NewGuid();
                    m.DomainSetID = resModuleData.data.DomainSetID;
                    m.ModuleID = resModuleData.data.ModuleID;
                    m.JSONName = m.JSONName.IsNullOrEmpty() ? m.Name : m.JSONName;
                });

                var res = await repository.AddListAsync(models);

                return ResultFactory.Success(res.data);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>BatchCreate=>Exception:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }

        public async Task<Result<List<ModuleFieldDto>>> GetList()
        {
            try
            {
                var res = await repository.GetListAsync();

                var dtoList = mapper.Map<List<ModuleFieldDto>>(res.data);

                return new Result<List<ModuleFieldDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetList=>Error:" + ex);
                return ResultFactory.Exception<List<ModuleFieldDto>>(ex);
            }
        }

        public async Task<Result<List<ModuleFieldDto>>> GetListByDataSetID(Guid dataSetID)
        {
            try
            {
                var res = await repository.GetListAsync(m => m.DomainSetID == dataSetID);

                var dtoList = mapper.Map<List<ModuleFieldDto>>(res.data);

                return new Result<List<ModuleFieldDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetListByDataSetID=>Error:" + ex);
                return ResultFactory.Exception<List<ModuleFieldDto>>(ex);
            }
        }

        public async Task<Result<ModuleFieldDto>> Get(Guid id)
        {
            try
            {
                var res = await repository.GetModelAsync(m => m.ID == id);

                var dtoModel = mapper.Map<ModuleFieldDto>(res.data);

                return new Result<ModuleFieldDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Get=>Error:" + ex);
                return ResultFactory.Exception<ModuleFieldDto>(ex);
            }
        }

        public async Task<Result<ModuleFieldDto>> Update(ModuleFieldParam moduleFieldParam)
        {
            try
            {
                var model = (await repository.GetModelAsync(m => m.ID == moduleFieldParam.ID)).data;

                var reqParam = moduleFieldParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Name, "字段名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.JSONName, "字段别名");

                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainSetID, nameof(reqParam.DomainSetID));
                ParamGuard.ValidateLength(reqParam.Name, "字段名称", 50);
                ParamGuard.ValidateLength(reqParam.JSONName, "字段别名", 50);
                ParamGuard.ValidateLength(reqParam.DefaultValue, "默认值", 50);
                ParamGuard.ValidateLength(reqParam.Caption, "说明", 50);

                if (model.JSONName.Replace(" ", "") != reqParam.JSONName.Replace(" ", ""))
                {
                    var notExistModelJSONName = (await repository.GetModelAsync(m => m.DomainSetID == reqParam.DomainSetID.Value && m.JSONName == reqParam.JSONName)).data;
                    ParamGuard.EnsureNotExist(notExistModelJSONName, $"字段别名:{reqParam.JSONName}已经存在");
                }

                if (model.Name.Replace(" ", "") != reqParam.Name.Replace(" ", ""))
                {
                    var notExistNameModelJSONName = (await repository.GetModelAsync(m => m.DomainSetID == reqParam.DomainSetID.Value && m.Name == reqParam.Name)).data;
                    ParamGuard.EnsureNotExist(notExistNameModelJSONName, $"字段名称:{reqParam.Name}已经存在");
                }



                model.Caption = moduleFieldParam.Caption;
                model.JSONName = moduleFieldParam.JSONName;
                model.Name = moduleFieldParam.Name;

                model.DomainultType = moduleFieldParam.DomainultType;
                model.DefaultValue = moduleFieldParam.DefaultValue;
                model.DomainType = moduleFieldParam.DomainType;
                model.Size = moduleFieldParam.Size;
                model.Precision = moduleFieldParam.Precision;

                //……

                var res = await repository.UpdateAsync(model);

                var dtoModel = mapper.Map<ModuleFieldDto>(res.data);

                return new Result<ModuleFieldDto>
                {
                    data = dtoModel,
                    code = res.code,
                    msg = res.msg
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Update=>Error:" + ex);
                return ResultFactory.Exception<ModuleFieldDto>(ex);
            }
        }

        public async Task<Result<string>> Delete(Guid id)
        {
            try
            {
                var res = await repository.DeleteAsync(m => m.ID == id);
                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Delete=>Error:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }

        /// <summary>
        /// API查询输出参数列表
        /// </summary>
        /// <param name="paging">分页</param>
        /// <param name="dataSetID">数据集ID</param>
        /// <param name="moduleID">模块ID</param>
        /// <returns></returns>
        public async Task<Result<List<ModuleFieldDto>>> GetListAsync(PagingInfo paging, Guid dataSetID, Guid moduleID)
        {
            var result = new Result<List<ModuleFieldDto>>();
            try
            {
                if (dataSetID != Guid.Empty)
                {
                    paging.SqlWhere.Append($" and DataSetID = '{dataSetID}' ");
                }
                else
                {
                    paging.SqlWhere.Append($" and ModuleID = '{moduleID}' ");
                }

                paging.OrderByList.Add("OrderNo", "ASC");
                var res = await repository.GetPagesAsync(paging);
                result.data = mapper.Map<List<ModuleFieldDto>>(res.data.Items);
                result.count = res.data.TotalItems;

            }
            catch (Exception ex)
            {
                result.code = (int)ApiEnum.Error;
                result.msg = ApiEnum.Error.GetEnumText();
                Log.Error($"{LogClassName}=>GetListAsync=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
            }

            result.result = true;
            result.code = (int)ApiEnum.Success;

            return result;
        }

        /// <summary>
        /// 删除API查询输出参数
        /// </summary>
        /// <param name="Ids">删除ID</param>
        /// <param name="dataSetId">模块集ID</param>
        /// <returns></returns>
        public Result<string> DelModuleFieldByIds(List<string> Ids, string dataSetId)
        {
            try
            {
                var res = repository.DelModuleFieldByIds(Ids, dataSetId);

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>DelModuleFieldByIds=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }
    }
}

					
			
					
					using AutoMapper;
using PTS2.BaseService;
using PTS2.Common;
using PTS2.Domain;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{
    public class ModuleFilterService : IModuleFilterService
    {
        private const string LogClassName = "ModuleFilterService";
        private readonly IMapper mapper;
        private readonly IModuleFilterRepository repository;
        private readonly IModuleDataRepository moduleDataRepository;

        private readonly ICommonService _commonService;
        public ModuleFilterService(IMapper _mapper,
            IModuleFilterRepository moduleFilterRepository,
            IModuleDataRepository _moduleDataRepository,
            ICommonService commonService)
        {
            mapper = _mapper;
            repository = moduleFilterRepository;
            moduleDataRepository = _moduleDataRepository;
            _commonService = commonService;
        }

        public async Task<Result<ModuleFilterDto>> Create(ModuleFilterParam moduleFilterParam)
        {
            try
            {
                #region 参数检查
                var reqParam = moduleFilterParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainSetID, nameof(reqParam.DomainSetID));
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Name, "参数名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Field, "字段名");

                ParamGuard.ValidateLength(reqParam.Name, "参数名称", 50);
                ParamGuard.ValidateLength(reqParam.Field, "字段名", 50);
                ParamGuard.ValidateLength(reqParam.Format, "格式", 20);
                ParamGuard.ValidateLength(reqParam.OutTrueResult, "返回成功", 50);
                ParamGuard.ValidateLength(reqParam.DefaultValue, "默认值", 50);

                if (!moduleFilterParam.DefaultCompare.IsNullOrEmpty())
                {
                    ParamGuard.EnsureSupports(reqParam.DefaultCompare, "比较运算符", ConstCompareOperators.SuppotsList);
                }
                var existModel = (await moduleDataRepository.GetModelAsync(m => m.DomainSetID == reqParam.DomainSetID.Value)).data;
                ParamGuard.EnsureExist(existModel, $"DataSetID:{reqParam.DomainSetID}不存在");

                // Name 重复检查
                var notExistModel = (await repository.GetModelAsync(m => m.Name == reqParam.Name
                                    && m.ModuleID == reqParam.ModuleID && m.DomainSetID == reqParam.DomainSetID)).data;
                ParamGuard.EnsureNotExist(notExistModel, $"参数名:{reqParam.Name}已经存在");

                // Field 重复检查
                var notExistFieldModel = (await repository.GetModelAsync(m => m.Field == reqParam.Field
                                    && m.ModuleID == reqParam.ModuleID && m.DomainSetID == reqParam.DomainSetID)).data;
                ParamGuard.EnsureNotExist(notExistFieldModel, $"字段名:{reqParam.Field}已经存在");

                reqParam.ModuleID = existModel.ModuleID;
                #endregion

                var model = mapper.Map<DataApi_ModuleFilter>(moduleFilterParam);
                model.ID = Guid.NewGuid();
                var maxOrderNo = _commonService.GetTableMaxField("DataApi_ModuleFilter", "OrderNo", $"DataSetID='{moduleFilterParam.DomainSetID}'");
                model.OrderNo = maxOrderNo.data;

                var res = await repository.AddAsync(model);

                var dtoModel = mapper.Map<ModuleFilterDto>(res.data);

                return ResultFactory.Success(dtoModel);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Create=>Error:" + ex);
                return ResultFactory.Exception<ModuleFilterDto>(ex);
            }
        }

        public async Task<Result<List<ModuleFilterDto>>> GetList()
        {
            try
            {
                var res = await repository.GetListAsync();

                var dtoList = mapper.Map<List<ModuleFilterDto>>(res.data);

                return new Result<List<ModuleFilterDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetList=>Error:" + ex);
                return ResultFactory.Exception<List<ModuleFilterDto>>(ex);
            }
        }

        public async Task<Result<List<ModuleFilterDto>>> GetListByDataSetID(Guid dataSetID)
        {
            try
            {
                var res = await repository.GetListAsync(m => m.DomainSetID == dataSetID);

                var dtoList = mapper.Map<List<ModuleFilterDto>>(res.data);

                return new Result<List<ModuleFilterDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetListByDataSetID=>Error:" + ex);
                return ResultFactory.Exception<List<ModuleFilterDto>>(ex);
            }
        }
        public async Task<Result<ModuleFilterDto>> Get(Guid id)
        {
            try
            {
                var res = await repository.GetModelAsync(m => m.ID == id);

                var dtoModel = mapper.Map<ModuleFilterDto>(res.data);

                return ResultFactory.Success(dtoModel);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Get=>Error:" + ex);
                return ResultFactory.Exception<ModuleFilterDto>(ex);
            }
        }

        public async Task<Result<ModuleFilterDto>> Update(ModuleFilterParam moduleFilterParam)
        {
            try
            {
                var model = (await repository.GetModelAsync(m => m.ID == moduleFilterParam.ID)).data;

                var reqParam = moduleFilterParam;
                ParamGuard.EnsureNotNullOrEmpty(reqParam.DomainSetID, nameof(reqParam.DomainSetID));
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Name, "参数名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Field, "字段名");

                ParamGuard.ValidateLength(reqParam.Name, "参数名称", 50);
                ParamGuard.ValidateLength(reqParam.Field, "字段名", 50);
                ParamGuard.ValidateLength(reqParam.Format, "格式", 20);
                ParamGuard.ValidateLength(reqParam.OutTrueResult, "返回成功", 50);
                ParamGuard.ValidateLength(reqParam.DefaultValue, "默认值", 50);

                if (!moduleFilterParam.DefaultCompare.IsNullOrEmpty())
                {
                    if (!ConstCompareOperators.SuppotsList.Contains(moduleFilterParam.DefaultCompare))
                    {
                        return ResultFactory.Error<ModuleFilterDto>($"比较运算符'{moduleFilterParam.DefaultCompare}'不支持");
                    }
                }

                if (model.Name.Replace(" ", "") != reqParam.Name.Replace(" ", ""))
                {
                    // Name 重复检查
                    var notExistModel = (await repository.GetModelAsync(m => m.Name == reqParam.Name
                                        && m.ModuleID == reqParam.ModuleID && m.DomainSetID == reqParam.DomainSetID)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"参数名:{reqParam.Name}已经存在");
                }

                if (model.Field.Replace(" ", "") != reqParam.Field.Replace(" ", ""))
                {
                    // Field 重复检查
                    var notExistFieldModel = (await repository.GetModelAsync(m => m.Field == reqParam.Field
                                        && m.ModuleID == reqParam.ModuleID && m.DomainSetID == reqParam.DomainSetID)).data;
                    ParamGuard.EnsureNotExist(notExistFieldModel, $"字段名:{reqParam.Field}已经存在");
                }

                model.Name = moduleFilterParam.Name;
                model.ItemSQL = moduleFilterParam.ItemSQL;
                model.bMust = moduleFilterParam.bMust;
                model.bOutParam = moduleFilterParam.bOutParam;
                model.bValue = moduleFilterParam.bValue;
                model.Caption = moduleFilterParam.Caption;
                model.Field = moduleFilterParam.Field;
                model.DefaultCompare = moduleFilterParam.DefaultCompare;
                model.DefaultValue = moduleFilterParam.DefaultValue;

                model.DomainType = moduleFilterParam.DomainType;
                model.DefaultType = moduleFilterParam.DefaultType;

                // ……

                var res = await repository.UpdateAsync(model);
                var dtoModel = mapper.Map<ModuleFilterDto>(res.data);
                return ResultFactory.Success(dtoModel);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Update=>Error:" + ex);
                return ResultFactory.Exception<ModuleFilterDto>(ex);
            }
        }

        public async Task<Result<string>> Delete(Guid id)
        {
            try
            {
                var res = await repository.DeleteAsync(m => m.ID == id);

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Delete=>Error:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }

        public async Task<Result<List<string>>> GetCompareOperatorList()
        {
            try
            {
                var list = ConstCompareOperators.SuppotsList;

                return await Task.FromResult(new Result<List<string>>()
                {
                    data = list
                });
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetCompareOperatorList=>Error:" + ex);
                return ResultFactory.Exception<List<string>>(ex);
            }
        }

        /// <summary>
        /// API查询过滤参数
        /// </summary>
        /// <param name="paging">分页</param>
        /// <param name="dataSetID">数据集ID</param>
        /// <param name="moduleID">模块ID</param>
        /// <returns></returns>
        public async Task<Result<List<ModuleFilterDto>>> GetListAsync(PagingInfo paging, Guid dataSetID, Guid moduleID)
        {
            var result = new Result<List<ModuleFilterDto>>();
            try
            {
                if (dataSetID != Guid.Empty)
                {
                    paging.SqlWhere.Append($" and DataSetID = '{dataSetID}' ");
                }
                else
                {
                    paging.SqlWhere.Append($" and ModuleID = '{moduleID}' ");
                }

                paging.OrderByList.Add("OrderNo", "ASC");
                var res = await repository.GetPagesAsync(paging);
                result.data = mapper.Map<List<ModuleFilterDto>>(res.data.Items);
                result.count = res.data.TotalItems;

            }
            catch (Exception ex)
            {
                result.code = (int)ApiEnum.Error;
                result.msg = ApiEnum.Error.GetEnumText();
                Log.Error($"{LogClassName}=>GetListAsync=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
            }

            result.result = true;
            result.code = (int)ApiEnum.Success;

            return result;
        }

        /// <summary>
        /// 删除API过滤参数
        /// </summary>
        /// <param name="Ids">删除ID</param>
        /// <param name="dataSetId">模块集ID</param>
        /// <returns></returns>
        public Result<string> DelModuleFilterByIds(List<string> Ids, string dataSetId)
        {
            try
            {
                var res = repository.DelModuleFilterByIds(Ids, dataSetId); ;

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>DelModuleFilterByIds=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }
    }
}

		using AutoMapper;
using PTS2.Common;
using PTS2.Domain.FilterModel.DomainApi;
using PTS2.Domain.Models.DomainApi;
using PTS2.Domain.Result.ModelDto.DomainApi;
using PTS2.DomainApiRepository.IRepository;
using PTS2.DomainApiService.IService;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTS2.DomainApiService.Service
{
    public class ModuleService : IModuleService
    {
        private const string LogClassName = "ModuleService";
        private readonly IMapper mapper;
        private readonly IModuleRepository repository;
        private readonly ICategoryRepository categoryRepository;
        public ModuleService(IMapper _mapper, IModuleRepository moduleRepository,
            ICategoryRepository _categoryRepository)
        {
            mapper = _mapper;
            repository = moduleRepository;
            categoryRepository = _categoryRepository;
        }

        public void DbFirstCreateModels(string path)
        {
            repository.DbFirstCreateModels(path);
        }

        public async Task<Result<ModuleDto>> Create(ModuleParam moduleParam)
        {
            try
            {
                #region 参数检查
                var reqParam = moduleParam;
                ParamGuard.ValidateLength(reqParam.Caption, "接口名称", 50);
                ParamGuard.ValidateLength(reqParam.Code, "接口代码", 30);
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Caption, "接口名称");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.Code, "接口代码");
                ParamGuard.EnsureNotNullOrEmpty(reqParam.CategoryID, nameof(reqParam.CategoryID));
                var existModel = (await categoryRepository.GetModelAsync(m => m.ID == reqParam.CategoryID)).data;
                ParamGuard.EnsureExist(existModel, $"CategoryID:{reqParam.CategoryID}不存在");
                var notExistModel = (await repository.GetModelAsync(m => m.Code == reqParam.Code && m.CategoryID == reqParam.CategoryID)).data;
                ParamGuard.EnsureNotExist(notExistModel, $"接口代码:{reqParam.Code}已经存在");
                var notExistCaptionModel = (await repository.GetModelAsync(m => m.Caption == reqParam.Caption && m.CategoryID == reqParam.CategoryID)).data;
                ParamGuard.EnsureNotExist(notExistCaptionModel, $"接口名称:{reqParam.Caption}已经存在");

                #endregion

                var model = mapper.Map<DataApi_Module>(moduleParam);
                model.ID = Guid.NewGuid();

                var res = await repository.AddAsync(model);
                var dtoModel = mapper.Map<ModuleDto>(res.data);
                return ResultFactory.Success(dtoModel);
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Create=>Error:" + ex);
                return ResultFactory.Exception<ModuleDto>(ex);
            }
        }

        public async Task<Result<List<ModuleDto>>> GetList()
        {
            try
            {
                var res = await repository.GetListAsync();

                var dtoList = mapper.Map<List<ModuleDto>>(res.data);

                return new Result<List<ModuleDto>>
                {
                    data = dtoList,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetList=>Error:" + ex);
                return ResultFactory.Exception<List<ModuleDto>>(ex);
            }
        }

        public async Task<Result<List<ModuleDto>>> GetListByCategory(Guid categoryID)
        {
            try
            {
                var resList = await repository.GetListAsync(m => m.CategoryID == categoryID);

                var dtoList = mapper.Map<List<ModuleDto>>(resList);

                var resData = new Result<List<ModuleDto>>
                {
                    data = dtoList,
                };
                return resData;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>GetListByCategory=>Error:" + ex);
                return ResultFactory.Exception<List<ModuleDto>>(ex);
            }
        }

        public async Task<Result<ModuleDto>> Update(ModuleParam moduleParam)
        {
            try
            {
                var reqParam = moduleParam;
                var model = (await repository.GetModelAsync(m => m.ID == moduleParam.ID)).data;
                ParamGuard.ValidateLength(reqParam.Caption, "接口名称", 50);
                ParamGuard.ValidateLength(reqParam.Code, "接口代码", 30);

                if (reqParam.Code.Replace(" ", "") != model.Code.Replace(" ", ""))
                {
                    var notExistModel = (await repository.GetModelAsync(m => m.Code == reqParam.Code && m.CategoryID == reqParam.CategoryID)).data;
                    ParamGuard.EnsureNotExist(notExistModel, $"接口代码:{reqParam.Code}已经存在");
                }

                if (reqParam.Caption.Replace(" ", "") != model.Caption.Replace(" ", ""))
                {
                    var notExistCaptionModel = (await repository.GetModelAsync(m => m.Caption == reqParam.Caption && m.CategoryID == reqParam.CategoryID)).data;
                    ParamGuard.EnsureNotExist(notExistCaptionModel, $"接口名称:{reqParam.Caption}已经存在");
                }


                model.Caption = moduleParam.Caption;
                model.CategoryID = moduleParam.CategoryID;
                model.Code = moduleParam.Code;
                model.bUse = moduleParam.bUse;
                model.Remark = moduleParam.Remark;

                // ……

                var res = await repository.UpdateAsync(model);

                var dtoModel = mapper.Map<ModuleDto>(res.data);

                return new Result<ModuleDto>
                {
                    data = dtoModel,
                };
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Update=>Error:" + ex);
                return ResultFactory.Exception<ModuleDto>(ex);
            }
        }

        public async Task<Result<ModuleDto>> Get(Guid id)
        {
            try
            {
                var model = (await repository.GetModelAsync(m => m.ID == id)).data;

                var dtoData = mapper.Map<ModuleDto>(model);

                var resData = new Result<ModuleDto>
                {
                    data = dtoData,
                };
                return resData;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Get=>Error:" + ex);
                return ResultFactory.Exception<ModuleDto>(ex);
            }
        }
        public async Task<Result<string>> Delete(Guid id)
        {
            try
            {
                var res = await repository.DeleteAsync(m => m.ID == id);

                var resData = new Result<string>
                {
                    data = res.data,
                };
                return resData;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>Delete=>Error:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }

        /// <summary>
        /// 删除API模块及关联模块
        /// </summary>
        /// <param name="Ids">模块ID</param>
        /// <returns></returns>
        public Result<string> DelModuleByIds(List<string> Ids)
        {
            try
            {
                var res = repository.DelModuleByIds(Ids); ;

                return res;
            }
            catch (Exception ex)
            {
                Log.Error($"{LogClassName}=>DelModuleByIds=>Error:" + ex.Message + "=>ErrorDetail:" + ex);
                return ResultFactory.Exception<string>(ex);
            }
        }
    }
}
					
					using System;
using System.Collections.Generic;
using System.Dynamic;

namespace PTS2.DomainApiService.Service
{

    public static class ExpandoObjectExtensions
    {
        public static ExpandoObject AddObject(this ExpandoObject dynamicObj, string key, object value)
        {
            ((IDictionary<string, object>)dynamicObj).Add(key, value);
            return dynamicObj;
        }
    }
}
			
					
					
					


					
					
					
					
					


					
					
					
					
					
